package com.huimv.guowei.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.SysCamera;
import com.huimv.guowei.admin.entity.SysCameraArea;
import com.huimv.guowei.admin.entity.vo.CameraBaseVo;
import com.huimv.guowei.admin.entity.vo.CameraListVo;
import com.huimv.guowei.admin.entity.vo.CameraNameDto;
import com.huimv.guowei.admin.mapper.SysCameraAreaMapper;
import com.huimv.guowei.admin.mapper.SysCameraMapper;
import com.huimv.guowei.admin.service.ISysCameraService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@Service
public class SysCameraServiceImpl extends ServiceImpl<SysCameraMapper, SysCamera> implements ISysCameraService {

    @Autowired
    private SysCameraMapper cameraBaseMapper;
    @Autowired
    private SysCameraAreaMapper cameraAreaMapper;
    @Override
    public Result listPage(CameraListVo cameraListVo) {
        Integer current = cameraListVo.getCurrent();
        String strchStr = cameraListVo.getStrchStr();
        Integer size = cameraListVo.getSize();
//        Integer areaId = cameraListVo.getAreaId();
        Integer sort = cameraListVo.getSort();
        Integer farmId = cameraListVo.getFarmId();
        Integer onLineStatus = cameraListVo.getOnLineStatus();
        String regionUuid = cameraListVo.getRegionUuid();
        QueryWrapper<SysCamera> wrapper = new QueryWrapper<>();
        if (null == current) {
            current = 1;
        }
        if (null == size) {
            size = 10;
        }
        if (farmId != null) {
            wrapper.eq("cb.farm_id", farmId);
        }
        if (StringUtils.isNotBlank(regionUuid)) {
            wrapper.eq("cb.region_uuid", regionUuid);
        }
        if (onLineStatus != null) {
            wrapper.eq("cb.on_line_status", onLineStatus);
        }
        if (StringUtils.isNotBlank(strchStr)) {
            wrapper.and(i -> i.like("cb.camera_name", strchStr));
        }
        if (sort == null) {
            wrapper.orderByDesc("cb.id");
        } else if (sort == 1) {
            wrapper.orderByDesc("cb.sort");
        } else {
            wrapper.orderByAsc("cb.sort");
        }
        wrapper.orderByDesc("cb.id");
        Page<SysCamera> page = new Page<>(current,size);
        IPage<CameraBaseVo> cameraBaseVoIPage = cameraBaseMapper.listPage(page, wrapper);
        return new Result(ResultCode.SUCCESS, cameraBaseVoIPage);
    }

    @Override
    public Result list(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        QueryWrapper<SysCameraArea> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId);
        List<SysCameraArea> cameraAreas = cameraAreaMapper.selectList(queryWrapper);

        List<CameraNameDto> cameraNameDtoList = new LinkedList();
        for (SysCameraArea cameraArea : cameraAreas) {
            CameraNameDto cameraNameDto = new CameraNameDto();
            QueryWrapper<SysCamera> baseQueryWrapper = new QueryWrapper<>();
            baseQueryWrapper.eq("farm_id", farmId).eq("area_name", cameraArea.getAreaName());
            List<SysCamera> cameraBases = cameraBaseMapper.selectList(baseQueryWrapper);

            cameraNameDto.setCameraBases(cameraBases);
            cameraNameDto.setId(cameraArea.getId());
            cameraNameDto.setAreaName(cameraArea.getAreaName());

            cameraNameDtoList.add(cameraNameDto);


        }

        return new Result(ResultCode.SUCCESS, cameraNameDtoList);
    }
}
